<?php
/**
 * Copyright (C) 2019 Leipzig University Library
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @author   Gregor Gawol <gawol@ub.uni-leipzig.de>
 * @author   Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 */

namespace fid\Controller;

use fid\Service\Client;
use Psr\Container\ContainerInterface;
use Symfony\Component\Serializer\SerializerInterface;
use VuFind\Auth\Manager as AuthManager;
use Zend\Form\Annotation\AnnotationBuilder;
use Zend\ServiceManager\ServiceLocatorInterface;
use Zend\Validator\ValidatorPluginManager;

class UserControllerFactory
{
    /**
     * @param ContainerInterface|ServiceLocatorInterface $container
     *
     * @return UserController
     */
    public function __invoke(ContainerInterface $container)
    {
        /** @var ValidatorPluginManager $plugins */
        $plugins = $container->get(ValidatorPluginManager::class);

        $builder = new AnnotationBuilder();
        $builder->getFormFactory()->getInputFilterFactory()
            ->getDefaultValidatorChain()->setPluginManager($plugins);

        /** @var Client $client */
        $client = $container->get(Client::class);
        /** @var AuthManager $authManager */
        $authManager = $container->get(AuthManager::class);

        /** @var SerializerInterface $serializer */
        $serializer = $container->get(SerializerInterface::class);

        return new UserController($container, $serializer, $authManager,
            $builder, $client);
    }
}