<?php
/**
 * Copyright (C) 2019 Leipzig University Library
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @author   Robert Lange <lange@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 */

namespace fid_bbi\Controller;

use VuFind\Controller\FeedbackController as BaseFeedbackController;


/**
 * Redirects the user to the appropriate default VuFind action.
 *
 * @category VuFind
 * @package  Controller
 * @author   Robert Lange <lange@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org Main Site
 */
class FeedbackController extends BaseFeedbackController
{
    /**
     * Send form data as email.
     *
     * @param string $recipientName  Recipient name
     * @param string $recipientEmail Recipient email
     * @param string $senderName     Sender name
     * @param string $senderEmail    Sender email
     * @param string $replyToName    Reply-to name
     * @param string $replyToEmail   Reply-to email
     * @param string $emailSubject   Email subject
     * @param string $emailMessage   Email message
     *
     * @return array with elements success:boolean, errorMessage:string (optional)
     */
    protected function sendEmail(
        $recipientName, $recipientEmail, $senderName, $senderEmail,
        $replyToName, $replyToEmail, $emailSubject, $emailMessage
    ) {
        if (strpos("emailSubject", $emailSubject) === false) {
            $emailSubject = "BBI ";
            $formId = $this->params()->fromRoute('id', $this->params()->fromQuery('id'));
            if (!empty($formId)) {
                switch ($formId) {
                    case "RegistrationRequest":
                        $emailSubject .= $this->translate("registration_form_title");
                        break;
                    case "FeedbackSite":
                        $emailSubject .= $this->translate("Contact");
                        break;
                }
            }
        }

        return parent::sendEmail(
            $recipientName,
            $recipientEmail,
            $senderName,
            $senderEmail,
            $replyToName,
            $replyToEmail,
            $emailSubject,
            $emailMessage
        );
    }
}
