<?php
/**
 * Default Controller
 *
 * PHP version 5
 *
 * Copyright (C) Villanova University 2010.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  Controller
 * @author   Demian Katz <demian.katz@villanova.edu>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org Main Site
 */
namespace fid_bbi\Controller;

use VuFind\Controller\SearchController as BaseSearchController;
use Zend\ServiceManager\ServiceLocatorInterface;

/**
 * Redirects the user to the appropriate default VuFind action.
 *
 * @category VuFind
 * @package  Controller
 * @author   Demian Katz <demian.katz@villanova.edu>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org Main Site
 */
class SearchController extends BaseSearchController
{
    /**
     * Home action
     *
     * @return mixed
     */
    public function sourcesAction()
    {
        $homepageFacet = key($this->getConfig('facets')->HomePage->toArray());
        if (empty($this->params()->fromQuery('facet'))) {
            return $this->redirect()->toRoute('search-sources',[],['query'=>['facet'=>$homepageFacet]]);
        }
        $view = $this->facetListAction();
        $facetList = $view->data;

        $whitelist = $this->getConfig('facets')->get('AllowFacetValue')->get($homepageFacet);
        if (!empty($whitelist)) {
            $whitelist = $whitelist->toArray();
            $facetList
                = array_filter(
                $facetList,
                function ($facet_info) use ($whitelist) {
                    return in_array($facet_info['value'], $whitelist);
                }
            );
        }
        $view->setVariable('data', $facetList);
        $view->setTemplate('search/sources.phtml');
        return $view;
    }
}
