<?php
/**
 * Record Driver Factory Class
 *
 * PHP version 5
 *
 * Copyright (C) Leipzig University Library 2014.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  RecordDrivers
 * @author   André Lahmann <lahmann@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development:plugins:hierarchy_components Wiki
 */
namespace fid_bbi\RecordDriver;

use Interop\Container\ContainerInterface;

/**
 * Record Driver Factory Class
 *
 * @category VuFind
 * @package  RecordDrivers
 * @author   André Lahmann <lahmann@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development:plugins:hierarchy_components Wiki
 *
 * @codeCoverageIgnore
 */
class Factory
{
    /**
     * Factory for SolrMarcFinc record driver.
     *
     * @param ContainerInterface $container Service manager.
     *
     * @return SolrMarcFinc
     */
    public static function getSolrMarcFinc(ContainerInterface $container)
    {
        $driver = new SolrMarcFinc(
            $container->get('VuFind\Config')->get('config'),
            null,
            $container->get('VuFind\Config')->get('searches')
        );
        $driver->attachILS(
            $container->get('VuFind\ILSConnection'),
            $container->get('VuFind\ILSHoldLogic'),
            $container->get('VuFind\ILSTitleHoldLogic')
        );
        $driver->attachSearchService($container->get('VuFind\Search'));
        return $driver;
    }
}
