<?php
/**
 * finc specific model for MARC records with a fullrecord in Solr.
 *
 * PHP version 5
 *
 * Copyright (C) Leipzig University Library 2015.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  RecordDrivers
 * @author   André Lahmann <lahmann@ub.uni-leipzig.de>
 * @author   Gregor Gawol <gawol@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     http://vufind.org/wiki/vufind2:record_drivers Wiki
 */
namespace fid_bbi\RecordDriver;

use VuFindSearch\Query\Query as Query;

/**
 * finc specific model for MARC records with a fullrecord in Solr.
 *
 * @category VuFind
 * @package  RecordDrivers
 * @author   André Lahmann <lahmann@ub.uni-leipzig.de>
 * @author   Gregor Gawol <gawol@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     http://vufind.org/wiki/vufind2:record_drivers Wiki
 */
trait SolrMarcFincTrait
{
    /**
     * Get an array of title detail lines with original notations combining
     * information from MARC field 245 and linked content in 880.
     *
     * @return array
     */
    public function getTitleDetails()
    {
        $title = '';

        if ($field = $this->getMarcRecord()->getField('245')) {
            if ($subfield = $field->getSubfield('a')) {
                // modified due to #13670
                // > Titel: 245$a $n $p $h $b $c
                $title = $subfield->getData();
                foreach (['n', 'p', 'h', 'b'] as $subkey) {
                    if ($subfield = $field->getSubfield($subkey)) {
                        $title .= ' ' . $subfield->getData();
                    }
                }
            }
        }
        if ($field = $this->getMarcRecord()->getField('249')) {
            // 249$a and 249$v are repeatable
            if ($subfields = $field->getSubfields('a')) {
                $vs = $field->getSubfields('v');
                foreach ($subfields as $i => $a) {
                    $title .= '. ' . $a->getData();
                    if (isset($vs[$i])) {
                        $title .= ' / ' . $vs[$i]->getData();
                    }
                }
            }
            // 249$b is non repeatable and applies to all $a$v combinations
            if ($field->getSubfield('b')) {
                $title .= ' : ' . $field->getSubfield('b')->getData();
            }
            // 249$c is non repeatable and applies to all $a$v combinations
            if ($field->getSubfield('c')) {
                $title .= ' / ' . $field->getSubfield('c')->getData();
            }
        }

        return array_merge(
            [$title],
            $this->getLinkedFieldArray('245', ['a', 'b', 'c'])
        );
    }
}
