<?php
/**
 * Factory for Root view helpers.
 *
 * PHP version 5
 *
 * Copyright (C) Villanova University 2014.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  View_Helpers
 * @author   Demian Katz <demian.katz@villanova.edu>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */
namespace fid_bbi\View\Helper\Root;

use Interop\Container\ContainerInterface;

/**
 * Factory for Root view helpers.
 *
 * @category VuFind
 * @package  View_Helpers
 * @author   Demian Katz <demian.katz@villanova.edu>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 *
 * @codeCoverageIgnore
 */
class Factory
{
    /**
     * Construct the Record helper.
     *
     * @param ContainerInterface $container Service manager.
     *
     * @return Record
     */
    public static function getRecord(ContainerInterface $container)
    {
        $return = new Record(
            $container->get('VuFind\Config')->get('config'),
            $container->get('ViewHelperManager')->get('url'),
            $container->get('VuFind\AuthManager'),
            $container->get('finc\Rewrite'),
            $container->get('VuFind\Config')->get('Resolver')
        );

        //due to https://github.com/vufind-org/vufind/pull/718
        //we have to explicitly add the cover router (cf. #
        $return->setCoverRouter($container->get('VuFind\Cover\Router'));

        return $return;
    }
}
